# Sample Test
## 说明
用于构建单元测试环境
## Installing Flask-Sample-Test
`pip install flask-sample-test`

## Get source code
`git clone https://github.com/December1208/flask_sample_test.git`


### Writing tests
```python

```
